pub struct Mix<B1, B2> {
pub b1: B1,
pub b2: B2,
pub factor: f32,
}Expand description
BSDF that can blend two arbitrary BSDF’s together
Fields
b1: B1b2: B2factor: f32Trait Implementations
Sourceimpl<B1, B2> BSDF for Mix<B1, B2>
impl<B1, B2> BSDF for Mix<B1, B2>
Sourcefn evaluate(&self, omega_o: Vec3d, omega_i: Vec3d) -> RgbD
fn evaluate(&self, omega_o: Vec3d, omega_i: Vec3d) -> RgbD
Returns the value of the BSDF at the given directions Read more
Sourcefn emission(&self, omega_o: Vec3d) -> RgbD
fn emission(&self, omega_o: Vec3d) -> RgbD
Returns how much light is emitted to the given direction
omega_oSourcefn sample_incoming(&self, omega_o: Vec3d, rdf: Vec3d) -> SampleIncomingResponse
fn sample_incoming(&self, omega_o: Vec3d, rdf: Vec3d) -> SampleIncomingResponse
Given a direction where light is scattered to, samples an incident direction, from which the light
may come from Read more
Sourcefn sample_outgoing(&self, omega_i: Vec3d, rdf: Vec3d) -> SampleOutgoingResponse
fn sample_outgoing(&self, omega_i: Vec3d, rdf: Vec3d) -> SampleOutgoingResponse
Given an incident light direction, samples a direction where light is scattered to Read more
Sourcefn sample_emission(&self, rd: Vec2d) -> SampleEmissionResponse
fn sample_emission(&self, rd: Vec2d) -> SampleEmissionResponse
Samples a direction in which light is emitted to and also returns the amount of emission
The returned vector is the null vector, if this surface does not emit any light
See also:
SampleEmissionResponseSourcefn sample_incoming_pdf(&self, omega_o: Vec3d, omega_i: Vec3d) -> f64
fn sample_incoming_pdf(&self, omega_o: Vec3d, omega_i: Vec3d) -> f64
Returns the probability density sampling an incoming direction given an outgoing direction
See
BSDF::sample_incoming and SampleIncomingResponseSourcefn sample_outgoing_pdf(&self, omega_o: Vec3d, omega_i: Vec3d) -> f64
fn sample_outgoing_pdf(&self, omega_o: Vec3d, omega_i: Vec3d) -> f64
Returns the probability density sampling an outgoing direction given an incoming direction
See
BSDF::sample_outgoing_pdf and SampleOutgoingResponseSourcefn sample_emission_pdf(&self, omega_o: Vec3d) -> f64
fn sample_emission_pdf(&self, omega_o: Vec3d) -> f64
Returns the probability density of choosing the given direction when sampled with
BSDF::sample_emission
Returns 0.0 if the surface does not emit lightSourcefn base_color(&self, omega_o: Vec3d) -> RgbD
fn base_color(&self, omega_o: Vec3d) -> RgbD
Returns the base color of the surface.
This function is used to generate auxiliary images for AI tools such as Open Image Denoise